@@ -4,3 +4,7 @@ from rgd_3d import models
 
 class Mesh3DDetailView(PermissionDetailView):
     model = models.Mesh3D
+
+
+class Tiles3DDetailView(PermissionDetailView):
+    model = models.Tiles3D
